@@ -224,7 +224,7 @@ bool VocabularyModel::setData(const QModelIndex &index, const QVariant &value, i
         return false;
     }
 
-    emit dataChanged(index, index);
+    Q_EMIT dataChanged(index, index);
     ///@todo trust dirty bit
     m_document->setModified();
     return true;
